@@ -3,3 +3,5 @@ from .deco_matrix import deco_matrix
 from .deco_node import deco
 from .deco_str import deco_str
 from .deco_vector import deco_vector
+from .deco_crostab import deco_crostab
+from .deco_table import deco_table
