@@ -5,4 +5,4 @@ def entries_margin(entries, head, tail, key_read, read, rule):
     return EntriesMargin \
         .build(entries, head, tail) \
         .stringify(key_read, read) \
-        .to_list(('..', '..') if rule is None else rule)
+        .to_list(rule)  # ('..', '..') if rule is None else rule
